ortho.OrthogonalFunctions
=========================

.. currentmodule:: ortho

.. autoclass:: OrthogonalFunctions
   :no-members:
   :no-inherited-members:
   :no-special-members:

  
   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         OrthogonalFunctions.check
         OrthogonalFunctions.plot
         OrthogonalFunctions.print
      
  

  
  
  